@@ -1,5 +1,3 @@
-from datetime import datetime
-
 from typing import Any
 
 from influxdb_client import InfluxDBClient, Point
@@ -13,6 +11,10 @@ class InfluxData:
         self._org = org
         self._bucket = bucket
 
+    @property
+    def bucket(self) -> str:
+        return self._bucket
+
     def write(self, point: Point):
         self._write_api.write(self._bucket, self._org, point)
 
